#
# spec file for package mpv
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 Packman Team <packman@links2linux.de>
# Copyright (c) 2012 Jiri Slaby <jslaby@suse.de>
# Copyright (c) 2011-2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _waf_ver 1.9.5
%define lname   libmpv1
Name:           mpv
Version:        0.22.0
Release:        70.2
Summary:        Advanced general-purpose multimedia player
# waf is licensed with BSD-3-Clause
License:        GPL-2.0+ and BSD-3-Clause
Group:          Productivity/Multimedia/Video/Players
Url:            http://mpv.io/
Source:         http://github.com/mpv-player/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# Can't use system one as it breaks quite often with updates
Source1:        http://waf.io/waf-%{_waf_ver}
Source2:        %{name}.changes
# PATCH-FIX-OPENSUSE do not require equal libav versions, obs rebuilds as needed
Patch0:         mpv-make-ffmpeg-version-check-non-fatal.patch
BuildRequires:  hicolor-icon-theme
Requires:       hicolor-icon-theme
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
BuildRequires:  ladspa-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmng-devel
BuildRequires:  linux-kernel-headers
BuildRequires:  lirc-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  pkg-config
BuildRequires:  python-docutils
BuildRequires:  update-desktop-files
BuildRequires:  yasm
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(caca)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(dvdnav) >= 4.2.0
BuildRequires:  pkgconfig(dvdread) >= 4.1.0
BuildRequires:  pkgconfig(enca)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(lcms2) >= 2.6
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libass) >= 0.12.1
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice) >= 55.0.0
BuildRequires:  pkgconfig(libavfilter) >= 5.0.0
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libbluray) >= 0.3.0
BuildRequires:  pkgconfig(libbs2b)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_cdda)
BuildRequires:  pkgconfig(libcdio_paranoia)
BuildRequires:  pkgconfig(libiso9660)
BuildRequires:  pkgconfig(libpulse) >= 1.0
BuildRequires:  pkgconfig(libswresample) >= 1.1.100
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libudf)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(libva-x11)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(openal) >= 1.13
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(smbclient)
BuildRequires:  pkgconfig(vdpau)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xscrnsaver)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
# Used via LUA scripts
Recommends:     youtube-dl
# Obsoletion of mplayer2 that is dead for 2 years now
Provides:       mplayer2 = 20140101
Obsoletes:      mplayer2 < 20140101
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# PDF manual.
# JIT for lua.
%if 0%{?suse_version} > 1320
BuildRequires:  python-rst2pdf
%ifarch %ix86 x86_64
BuildRequires:  pkgconfig(luajit)
%endif
%endif
%if 0%{?suse_version} != 1315
# Testing framework: disabled for now as it runs just 1 test
# BuildRequires:  pkgconfig(cmocka) >= 0.4.1
# Wayland and libguess.
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(libguess)
%if 0%{?suse_version} > 1310
BuildRequires:  pkgconfig(wayland-client) >= 1.6.0
BuildRequires:  pkgconfig(wayland-cursor) >= 1.6.0
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(xkbcommon) >= 0.3.0
%endif
%endif

%description
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

%package devel
Summary:        A library to link together with mpv player
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

This package contains all the development files.

%package -n %{lname}
Summary:        A library to link together with mpv player
Group:          System/Libraries

%description -n %{lname}
mpv is a movie player based on MPlayer and mplayer2. It supports a wide variety
of video file formats, audio and video codecs, and subtitle types.

This package contains a library that can other apps use to utilize the mpv
features.

%prep
%setup -q
%patch0 -p1

# As we downloaded specific waf version we need to put and prepare it in place.
cp -f %{SOURCE1} waf
chmod a+x waf

# I hate UNKNOWN so lets put decent info there.
MODIFIED="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE2}")"
DATE="$(date -d "$MODIFIED" "+%%b %%e %%Y")"
sed -i "s|UNKNOWN|$DATE|g;s|VERSION|\"%{version}\"|g" common/version.c

%build
# SDL: disable as it is pointless to have on Linux, it is Windows/OS X fallback.
myopts="--disable-sdl1 --disable-sdl2"
# We don't want to rebuild all the time.
myopts+=" --disable-build-date"
# Debug just adds -g and we do that over optflags anyway.
myopts+=" --disable-debug"
export CCFLAGS="%{optflags}"
./waf configure \
  --prefix="%{_prefix}"              \
  --bindir="%{_bindir}"              \
  --mandir="%{_mandir}"              \
  --libdir="%{_libdir}"              \
  --docdir="%{_docdir}/%{name}"      \
  --confdir="%{_sysconfdir}/%{name}" \
  --enable-openal                    \
  --enable-cdda                      \
  --enable-libmpv-shared             \
  --enable-zsh-comp                  \
  --enable-manpage-build             \
  --enable-libarchive                \
%if 0%{?suse_version} > 1320
  --enable-pdf-build                 \
%endif
  ${myopts}

./waf build --verbose %{?_smp_mflags}

%install
./waf --destdir=%{buildroot} install

install -D -m 0644 etc/input.conf %{buildroot}%{_sysconfdir}/%{name}/input.conf
install -D -m 0644 etc/mpv.conf %{buildroot}%{_sysconfdir}/%{name}/mpv.conf

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%if 0%{?suse_version} > 1320
%doc build/DOCS/man/mpv.pdf
%endif
%doc Copyright LICENSE README.md RELEASE_NOTES
%dir %{_sysconfdir}/%{name}/
%config %{_sysconfdir}/%{name}/encoding-profiles.conf
%config %{_sysconfdir}/%{name}/input.conf
%config %{_sysconfdir}/%{name}/mpv.conf
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor
#zsh completion
%{_datadir}/zsh/site-functions/_mpv
%{_mandir}/man?/%{name}.?%{?ext_man}

%files -n %{lname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Sun Nov 20 2016 aloisio@gmx.com
- Update to version 0.22.0
  Added features:
  * audio/out: add AudioUnit output driver for iOS
  * demux_mkv: parse Matroska colorimetry metadata
  * filter_kernels: add ability to taper kernels/windows, add
    tukey window
  * osc: add seekbarstyle=knob (#2365)
  * video/out: add tct as modern caca alternative for
    true-color and 256-color terminals
  * video: add --hwdec=vdpau-copy mode
  Deprecated features:
  * vf_vdpaurb: deprecated in favor of --hwdec=vdpau-copy
  Added options and commands
  * --opengl-early-flush=auto
  * --scale-taper, --scale-wtaper
  * --scale-wblur
  * macOS: --hidpi-window-scale (#3716)
  * osc: add script message handlers for
    chapter/track/playlists
  Fixes and Minor Enhancements
  * Apply --autofit-larger after --autofit-smaller (#3753)
  * Set subtitle track title to indicate hearing/visual
    impaired tracks
  * ao_alsa: disable chmap API use for mono/stereo (#2905,
    [#3045])
  * build: add required failure message for libavfilter check
    (#3692)
  * build: fix compilation with mingw-w64/Clang (#3800)
  * build: make VideoToolbox available on iOS
  * command: fix reset-on-next-file=all and tv-freq option
    (#3708)
  * command: if window-scale can't be set properly, set it as
    option (#3724)
  * demux_mkv: don't recursively resolve timeline for opened
    reference files
  * demux_mkv: fix ordered chapter sources with ordered
    editions
  * opengl: compile against iOS OpenGLES implementation
  * options: handle legacy no-* sub-options
  * osc: add alpha animation to tooltip (fix lingering tooltip)
  * osc: change default deadzonesize to 0.5
  * osc: don't wrap the title
  * osc: fix crash after reaching a certain position in
    limited lists (#3691)
  * osc: fix crash with no chapters
  * osc: fix crashes when dragging seekbar across file changes
    (#3210)
  * osc: fix displaying only half of the entries when at the
    end of a list
  * osc: fix missing chapter ticks with seekbarstyle=bar
  * osc: slimbox: fix clipping with seekbarstyle=bar (#3737)
  * osc: top/bottombar: also scale when min-width is reached
    to match box/slimbox behavior
  * osc: top/bottombar: dynamically size timecodes according
    to timems
  * osc: top/bottombar: rescale layout to same size with
    scale=1
  * osc: top/bottombar: scale title if too large like box
  * player: consistently initialize screensaver state with
  - -force-window
  * player: enable no-video subtitle display on coverart too
  * player: make --start-time work with --rebase-start-time=no
  * player: make sure non-video subtitle rendering is reset if
    video resumes (#3770)
  * player: removing last playlist entry while looping should
    not stop (#3808)
  * player: show subtitles on VO if --force-window is used
    (#3684)
  * player: speed up audio/video re-sync when there is a huge
    delay
  * vdpau: fix hwdec uninit (#3788)
  * vo_opengl: blend against background color for --alpha=blend
  * vo_opengl: context_rpi: fix stdatomic usage (#3699)
  * vo_opengl: fix --blend-subtitles handling (#3773)
  * vo_opengl: fix redrawing with hardware decoding (#3773)
  * vo_opengl: partially re-enable glFlush() calls (#3670)
  * ytdl_hook: sort chapters by time
* Fri Nov  4 2016 tchvatal@suse.com
- Add patch to not require equal libav soname version we were built with
  OBS rebuilds packages as needed and it is over the head bsc#1012600
  * mpv-make-ffmpeg-version-check-non-fatal.patch
* Wed Oct 19 2016 aloisio@gmx.com
- Update to version 0.21.0
  Added features:
  * config: allow profile forward-references in default profile
  * demux_lavf: "support" mov edit lists and log errors if
    used (FFmpeg only)
  * hwdec: Add support for CUDA and cuvid/NvDecode (mostly
    useful on Linux where VDPAU still lacks HEVC Main 10
    support; keep using DXVA2 on Windows)
  * osc: add right-click behavior to playlist and chapter
    buttons
  * osc: add user-alterable margin for top/bottombar
  * rpi: add --hwdec=rpi-copy (#3604)
  * sd_lavc: enable teletext
  * vaapi: support drm devices when running in vaapi-copy mode
  * vd_lavc: Add hwdec wrapper for crystalhd
  * vo_opengl: add hw overlay support and use it for RPI
  * vo_opengl: basic mali fbdev support
  * vo_opengl: rpi: merge vo_rpi features
  Removed features:
  * vo_opengl: remove pre/post/scale-shaders in favor of
    user-shaders
  Deprecated features:
  * config: deprecate ao and vo auto-profiles
  * vo_rpi: deprecate this VO
    Added options and commands:
  * add --teletext-page option
  * af_pan: add af-command support to change the matrix
  * af_rubberband: add af-command and option to change the
    pitch
  * command: add a load-script command
  * command: add a video-dec-params property
  * command: add an apply-profile command
  * command: add audio-pts property to get the audio pts
  * command: add options to property list
  * command: add sub-text property for current subtitle text
  * command: export profile list as a property (#977)
  * options: add --hwdec=yes as alias for --hwdec=auto
  * player: add --player-operation-mode=pseudo-gui
  * player: add --video-osd=no option to disable video OSD
    (#3387)
  * player: add --watch-later-directory option
  * stream_bluray: select title by playlist
    (bd://mpls/[playlist])
  * vo_opengl: disable glFlush() by default, and add an option
    to enable it for testing
  Changed options and commands:
  * af_rubberband: default to channels=together
  * command: allow absolute seeks relative to end of stream
  * command: make bitrate properties observable
  * command: make most options observable
  * msg: make --log-file and --dump-stats accept config path
    expansion (#3591)
  * options: deprecate --playlist-pos to --playlist-start
  * options: make input options generally runtime-settable
  * options: rename subtitle options (--sub-text- → --sub;
  - -ass- → --sub-ass-)
  * osc: change default layout to bottombar, seekbarstyle to
    bar, use larger scalewindowed and scalefullscreen
  * player: make --terminal, --log-file, --dump-stats, --osc,
  - -ytdl, --audio-*, --priority, --stop-screensaver (#3615)
    settable at runtime
  * vo_drm: change CLI options
    + Change connector selection to accept human readable
    names (such as eDP-1, HDMI-A-2) rather than arbitrary
    numbers.
    + Change GPU selection to accept GPU number rather than
    device paths.
    + Merge connector and GPU selection into one
  - -drm-connector.
    + Add support for --drm-connector=help.
    + Add support for --drm-* in EGL backend.
  * vo_opengl: rename 3dlut-size to icc-3dlut-size
  Removed options and commands:
  * command: remove hwdec-active and hwdec-detected properties
  * command: remove vo-cmdline
  * options: drop unreferenced --bluray-angle option
  * vo, ao: disable positional parameter suboptions
  * vo_xv: replace no-colorkey with ck-method=none
  Deprecated options and commands:
  * all VOs and AOs: deprecate sub-options, add them as global
    options
  * command: deprecate "cache" property, replace with
    "cache-percent"
  * deprecate --vo-defaults
  * deprecate --vo=opengl-hq alias in favor of opengl-hq
    profile
  * options: deprecate --mute=auto
  * vo_direct3d: deprecate direct3d_shaders alias, use shaders
    by default
  * vo_opengl: deprecate 'drm-egl' backend and introduce 'drm'
    instead
  Fixes and minor enhancements:
  * TOOLS/zsh.pl: die if we can't parse main options
  * TOOLS/zsh.pl: don't filter files by extension (#2273)
  * ao_alsa: try to fallback to "hdmi" before "iec958" for
    spdif
  * ao_rsound: fix compilation (#3501)
  * aspect: use nominal width instead of actual width for
    video-unscaled
  * audio/out: prevent underruns with spdif under certain
    conditions
  * audio: fix late audio start (#3610)
  * audio: fix missed wakeup when changing audio output device
  * audio: fix segfault when yanking USB DAC
  * charset_conv: Use CP949 instead of EUC-KR
  * command: don't log "ignore" command with -v verbosity
  * command: try selecting the next track if track switching
    fails (#3446)
  * demux_mkv: don't crash if --ordered-chapters-files fails
  * displayconfig: treat a refresh rate of 1 as invalid
  * ipc: log when listening to IPC socket (#3598)
  * macOS: fix fullscreen regression on 10.11 and newer (#3364)
  * mp_image: fix clearing to black with p010 format
  * osc: Fix scaling issues when toggling fullscreen (#3429)
  * osc: align text vertically in top/bottombar (#2093)
  * osc: change seekbar background's alpha scaling
  * osc: fix display of chapters and playlist scaling
  * osc: move tooltip to inside seekbar for top/bottombar
  * osc: show playlist/chapter list on prev/next instead of osd
  * path: default ~~ paths to home directory (#3591)
  * player: do not let pseudo-gui override user config settings
  * player: enable reading from stdin after loading input.conf
  * player: fix instant subtitle refresh on track switches
  * player: make --force-window work with opengl-cb
  * stream_file: don't use poll() on directories (would hang
    on macOS; #3530, #3649)
  * stream_lavf: fix determining seekability (#1701)
  * sub: actually apply text alignment options to non-ASS
    subtitles
  * terminal-win: support modifier keys in console input
    (#3625)
  * vo_drm: fix segfault when using invalid card
  * vo_opengl: apply 90° rotation to chroma texture size
    (#3568)
  * vo_opengl: fix incorrect video rendering after vdpau
    preemption recovery
  * vo_opengl: partially fix dumb-mode cropping with rotation
  * vo_opengl: rpi: use overlay for yuv420p too
  * w32_common: initialize playback status as soon as possible
    (#3482)
  * wayland: reject resize events with either dimension being
    0 (#3679)
  * x11: fix external fullscreen update (#3570)
  * ytdl_hook: Add title to playlist items if available
  * ytdl_hook: Set aspect ratio for anamorphic video
  * ytdl_hook: Support playlist entries without subtitles
  * ytdl_hook: add chapters by parsing video's description
  * ytdl_hook: don't add subtitles with unknown duration
  * ytdl_hook: temporarily force disable dash segments formats
- Update waf to 1.9.5
* Sat Oct 15 2016 mpluskal@suse.com
- Enable libarchive support
* Fri Sep  2 2016 idonmez@suse.com
- Add exact dependency on all libav* packages not just libavcodec.
* Fri Aug 26 2016 aloisio@gmx.com
- Update to version 0.20.0
  Added options and commands:
  * aspect: add --video-unscaled=downscale-big
  * player: add --image-display-duration option to control
    duration of image display (#3425)
  * vo_opengl: angle: new flag (dcomposition) to control
    DirectComposition
  Fixes and minor enhancements:
  * af_lavrresample: fix error if resampler could not be
    recreated
  * audio: avoid missed wakeups with ab-loops
  * audio: do not apply --audio-channels if spdif passthrough is
    in use (#3445)
  * cache: don't use a backbuffer if the cache is as large as
    the file
  * command: prevent O(n^2) behaviour for playlist property
  * demux: close underlying stream if it's fully read anyway
    (#3456)
  * demux: fix undefined behavior with ogg metadata update
    (#3451)
  * player: make looping slightly more seamless
  * player: refresh very low framerate video on filter changes
    (#3435)
  * stream_memory: disable stream cache
  * vf_rotate: allow arbitrary rotation (#3434)
  * vo: be more trusting to estimated display FPS (#3433)
  * w32_common: use hooks to detect parent window resize
  * x11: work around mutter fullscreen issue (#2072)
  * This listing is not complete. Check
    DOCS/client-api-changes.rst for a history
    of changes to the client API, and DOCS/interface-changes.rst
    for a history of changes to other user-visible interfaces.
* Mon Aug 15 2016 aloisio@gmx.com
- Update to version 0.19.0
  Build system changes:
  * build: add --htmldir option
  * build: always require atomics
  * wscript: add proper unversioned SONAME for Android
  New features:
  * client API: add stream_cb API for user-defined stream
    implementations (bumps client API version to 1.22)
  * vf_d3d11vpp: add video processor selection
  * videotoolbox: add --hwdec=videotoolbox-copy for h/w
    accelerated decoding with video filters
  * vo_opengl: add a tscale=linear direct implementation
  Removed features:
  * audio/filter: remove delay audio filter
  Added options and commands:
  * command: add filename/no-ext sub-property that returns
    filename without extension (#3404)
  * command: add properties for HDR metadata
  * command: add replaygain information properties to
    track-list
  * options: add vp9 to --hwdec-codecs
  * player: add --audio-stream-silence
  * player: add --audio-wait-open
  * player: add --no-autoload-files
  * videotoolbox: add yuv420p to --videotoolbox-format
  Changed options and commands:
  * options: un-restrict --audio-delay
  * use - as command-name separator everywhere
  * vo_opengl: reduce default 3dlut-size to 64x64x64 (since
    accuracy is improved)
  Deprecated options and commands:
  * deprecate "balance" option/property (no replacement)
  Fixes and Minor Enhancements:
  * Windows: don't wait for GUI thread when polling for
    events (#3393)
  * af_lavcac3enc: error out properly if encoding fails
  * af_volume: don't let softvol overwrite af_volume
    volumedb sub-option
  * ao_pulse: fix some volume control rounding issues
  * ao_wasapi: in exclusive mode, do not output multichannel
    by default
  * audio: add heuristic to move auto-downmixing before
    other filters
  * audio: show an osd bar when changing ao-volume
  * demux: make ALBUM replaygain tags optional (#3405)
  * demux_raw: fix small typo to add s16be support
  * demux_timeline: restore mkv edition switching
  * libarchive: sanitize non-UTF8 archive entries
  * macOS/vo_opengl: fix crash when glctx is NULL during
    init (#3360)
  * player: disable display-sync with spdif transcoding
  * player: do not cut off terminal status line if it
    contains newlines (#3340)
  * player: fix display-sync timing if audio resumes slowly
  * player: improve instant track switching (#3392)
  * player: improve non-hr seeking with external audio tracks
  * player: offset demuxer on start/seek properly with
    audio/sub delay
  * player: sync audio as well when enabling it mid-stream
  * stream/stream_bluray: display list of available titles
    in verbose mode
  * sub: don't potentially discard too many subtitles on seek
  * video: respect --deinterlace=auto
  * vo_direct3d: add missing header (fixes Cygwin build)
  * vo_opengl: angle: try D3D9 when D3D11 fails eglInitialize
  * vo_opengl: angle: use WARP if there are no hw adapters
    (makes it work on Windows 7 without hardware-accelerated
    graphics)
  * vo_opengl: increase 3DLUT accuracy at smaller LUT sizes
  * vo_opengl: remove the 3dlut-size npot2 restriction
  * vo_wayland: fix high CPU usage due to busy polling
  * wayland_common: clip window size to the display output
    size
  * wayland_common: fix crashes when switching to fullscreen
    before the video output is fully initialized
  * wayland_common: fix fullscreen image switching bug
  * wayland_common: prevent black bars on most non-native
    aspect ratios
  * wayland_common: remove untested/unusable wayland dnd code
  * win32: mpv.rc: re-add version info
  * x11: skip ICC update on every window move
  * ytdl: Error out with http_dash_segments (unsupported for
    now)
- Updated waf to 1.9.2
* Tue Jul 12 2016 tchvatal@suse.com
- Update waf to 1.9.1
* Tue Jul 12 2016 mpluskal@suse.com
- Force rebuilding with every minor update of ffmpeg
* Sun Jul 10 2016 aloisio@gmx.com
- Update to version 0.18.1
  * Note: Running mpv with different versions of the
    FFmpeg/Libav libraries than it was compiled with
    is no longer supported. Even supposedly ABI-compatible
    versions have been a source of trouble, and it creates
    far too much complexity with little to no benefit,
    coupled with absurd and unusable FFmpeg API artifacts.
    Instead, mpv will exit with an error when such a
    situation is detected.
    This simply means that mpv needs to be rebuilt whenever
    FFmpeg libraries change.
  New Features:
  * d3d: implement screenshots for --hwdec=d3d11va
  * vo_opengl: add output_size uniform to custom shader
  * vo_opengl: implement the Panasonic V-Log function
    (#3157)
  * vo_opengl: implement ARIB STD-B68 (HLG) HDR TRC
  Options and oommands:
  * command: pack sub image data in overlay-add command
  * options: deprecate --heartbeat-cmd
  * audio: deprecate --softvol
  * audio: drop --softvol=no and --softvol=auto (#3322)
  Fixes and minor enhancements:
  * video: fix deinterlace filter handling on pixel
    format changes
  * x11: silence xdg-screensaver
  * vo_opengl: angle: update the swapchain on resize
    (#3301)
  * vo_opengl: error out gracefully when trying to use
    FBOs without FBO API
  * vd_lavc: expose mastering display side data reference
    peak (improves results with HDR content)
  * vo_opengl: generalize HDR tone mapping mechanism
    (#3293)
  * vo_opengl: don't constantly resize the output FBO
  * vo_opengl: use ringbuffer of PBOs
  * Windows: make WM_NCHITTEST simpler and more accurate
  * ao_oss: do not add an entry to audio-device-list if
    device file missing
  * dec_audio: fix segment boudnary switching
  * ao_lavc, vo_lavc: Migrate to new FFmpeg encoding API
  * vo_opengl: explicitly use main framebuffer when
    reading window content (#3284)
  * vo_xv: fix behavior with odd sizes
  * audio: insert auto-inserted filters at end of chain
  * x11: add missing FocusChangeMask (disables key repeat
    when losing focus while a key is down)
  * ao_coreaudio: error out when selecting invalid device
  * ad_lavc: work around misbehavior of some FFmpeg
    decoders like wmapro (#3297)
  * player: cut off status line on terminal width
* Sun Jun 26 2016 virtuousfox@gmail.com
- Remove mpv_gpl3 Packman condition due to upstream's decision
  to drop "prescaling" code in favour of generic shader hooks.
* Sat Jun 25 2016 aloisio@gmx.com
- Update to version 0.18.0
  Build System Changes:
  * build: Do not link to libGL for egl-drm
  * build: also use the iconv check on FreeBSD
  * build: don't install tests, only build them
  * build: re-enable encoding mode by default
  * vo_opengl: hwdec: remove build-dependency on dxva2 (#3150)
  * wscript: make at least 1 OpenGL output mandatory
  New features:
  * csputils: add SMPTE ST2084 support
  * demux_mkv: support Matroska webvtt (#3247)
  * demux_playlist: read directories recursively
  * stream_memory: add hex:// protocol
  * vf_crop: support opaque hardware decoding formats
  * vf_d3d11vpp: add a D3D11 video processor filter
  * vo_opengl: D3D11VA + ANGLE interop
  * vo_opengl: add an angle-es2 backend
  * vo_opengl: angle: dynamically load ANGLE
  * vo_opengl: d3d11egl: native NV12 sampling support
  * vo_opengl: enable color management on GLES
  * vo_opengl: implement HDR (SMPTE ST2084)
  * vo_opengl: implement tone mapping algorithms
  * vo_opengl: make PBOs work on GLES 3.x
  * vo_opengl: support external user hooks, enhancing the
    flexibility of user shaders
  * vo_opengl: vdpau interop without RGB conversion
  * wayland: implement HIDPI support
  Removed features:
  * vo_opengl: remove nnedi3 prescaler (replaced by user shaders)
  * vo_opengl: remove prescaling framework with superxbr prescaler
    (replaced by user shaders)
  Added options and commands:
  * Windows: make taskbar progress indication optional (#2535)
  * af_lavcac3enc: make encoder configurable
  * command: add playlist-pos-1 property (#2828)
  * command: introduce hwdec-current and hwdec-interop properties.
  * options: add --fit-border video option (currently Windows only)
  * video: add --hwdec=auto-copy mode
  * vo_opengl: always autoselect ANGLE as backend if available
  * vo_opengl: expose performance timers as properties
  * x11: add --x11-bypass-compositor=never
  * x11: extend --x11-bypass-compositor with fs-only option (#2582)
  Changed options and commands:
  * command: allow setting panscan etc. properties if no video is
    active
  * command: don't seek immediately when setting a-b loop while
    paused
  * command: if only ab-loop-b is set, loop from start of file
  * options: --geometry: center window position after applying
    size (#2397)
  * player: loop on end of file if ab-loop-b is unset
  * sd_add: replace --sub-ass=no with --ass-style-override=strip
  Removed options and commands:
  * vo_opengl: remove non-working rgb/rgba FBO formats
  Fixes and minor enhancements:
  * TOOLS/zsh.pl: add .f4v extension in zsh completions
  * TOOLS/zsh.pl: complete --audio-device
  * Windows: center window on original window center on resize to
    fit screen
  * Windows: fix size calculations for window resize (#2935)
  * Windows: fix wrong behavior with window-scale when window size
    exceeds screen size
  * Windows: make VOCTRL_SET_UNFS_WINDOW_SIZE resize the window
    around its center (#3164)
  * af_lavcac3enc: fix custom bitrates
  * ao_alsa: add more workarounds for hardware with broken drivers
    (e.g. ODROID-C2)
  * ao_opensles: remove 32-bit audio formats (not supported by
    Android)
  * cocoa: fix actual display refresh rate retrieval
  * cocoa: use displaylink without manually tracking the display
    id (#2392)
  * command: improve playlist* properties change notifications
    (#3267)
  * command: slightly nicer OSD list formatting
  * compatibility with recent FFmpeg APIs
  * d3d: fix hardware decoding of most MPEG2 things
  * d3dva: move Intel_H264_NoFGT_ClearVideo to lower priority
    (#3059)
  * demux_mkv: better resync behavior for broken google-created
    webms
  * demux_mkv: fix seeking with files that miss the first index
    entry
  * demux_playlist: recognize m3u8 as playlist extension (#3154)
  * input: fix parsing multiple input command prefixes
  * lcms: don't warn/error on 3dlut cache misses
  * lcms: improve black point handling (especially BT.1886)
  * macOS: handle multiple dropped files on the window (#3076)
  * player: always show the first frame in DS mode
  * player: assume video forwards timestamps jumps only with some
    formats (#3027)
  * player: do not update OSD all the time when paused
  * player: eagerly redraw OSD when seeking with coverart
  * player: fix use-after-free with --screenshot-directory (#3049)
  * player: force VO reconfig when unselecting video track
  * player: really start audio only once video is ready
  * sd_lavc: work around bug in older FFmpeg releases (#3109)
  * stream_cdda: enable cache by default
  * sub: fix --sub-gauss
  * vd_lavc: better hwdec wrapper decoder selection
  * vo_opengl: EGL: fix hwdec probing
  * vo_opengl: angle: avoid fullscreen FBO copy for flipping
  * vo_opengl: angle: enable DirectComposition (lowers vsync
    jitter)
  * vo_opengl: angle: prevent DXGI hooking Alt+Enter
  * vo_opengl: avoid outputting ultra-wide-gamut by default
  * vo_opengl: correctly disable interpolation if tscale can't be
    used
  * vo_opengl: fix bicubic_fast in ES mode
  * vo_opengl: fix d3d11 hardware decoding probing on Windows 7
  * vo_opengl: improve scale=oversample performance
  * vo_opengl: make the screen blue on shader errors
  * vo_opengl: partially fix 0bgr format support
  * vo_opengl: possibly update icc profile after changing options
  * vo_opengl: request core profile on X11/EGL too
  * vo_opengl: require at least ES 3.0 for float textures
  * vo_opengl: vdpau: fix certain cases of preemption recovery
    failures
  * vo_rpi: attempt to survive display mode changes
  * vo_rpi: fix destroying overlays (#3100)
  * vo_rpi: wait for vsync with a timeout
  * vo_sdl: fix pixel formats.
  * vo_xv: Handle incorrect size returned by Xv(Shm)CreateImage
    (#320)
  * wayland: correctly report display refresh rate
  * wayland: use the advertised size in fullscreen (#3021, #2657)
  * x11: tell GNOME to use dark window decorations
  * ytdl_hook: fix brightcove urls
  * ytdl_hook: just check if protocol is rtmp (#3090)
  * ytdl_hook: support multi-arc subtitles
- Re-added /etc/mpv/encoding-profiles.conf
* Tue Apr 12 2016 mpluskal@suse.com
- Update dependencies of desktop and icon handling scriplets
* Mon Apr 11 2016 aloisio@gmx.com
- Update to version 0.17.0
  * See https://github.com/mpv-player/mpv/releases/tag/v0.17.0
    for full changelog
* Mon Feb 29 2016 idonmez@suse.com
- Update to v0.16.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.16.0
    for the complete changelog.
- Drop mpv-0.15.0_fix_NULL_ptr.patch, fixed upstream.
- Don't install mpv.png as upstream now ships a mpv.svg
* Mon Feb 15 2016 virtuousfox@gmail.com
- Add a mpv_gpl3 condition to build mpv as GPL-3.0+ on Packman.
* Fri Jan 22 2016 idonmez@suse.com
- Drop the --enable-gpl3 options and revert the license to GPL-2.0+
* Wed Jan 20 2016 aloisio@gmx.com
- Backported commit 5053f4c to fix hang problem with smplayer
  (bug ref. #2729) mpv-0.15.0_fix_NULL_ptr.patch
* Mon Jan 18 2016 idonmez@suse.com
- Update to v0.15.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.15.0
    for the complete changelog.
- Install mpv.conf & input.conf
* Sun Jan 10 2016 idonmez@suse.com
- Set license to GPL-3.0+ so we can enable more OpenGL functionality.
- Add pkgconfig(gl) build dependency.
* Thu Dec 24 2015 tchvatal@suse.com
- Provide and obsolete mplayer2 as per packman discussion
* Mon Dec 14 2015 idonmez@suse.com
- Update to v0.14.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.14.0
    for the complete changelog.
* Fri Dec 11 2015 tchvatal@suse.com
- Remove mpg123 as dependency, thus losing need of being on packman.
  We use the mad implementation anyway if we had FPU and everything
  we support has to have it anyway.
* Fri Dec 11 2015 tchvatal@suse.com
- Sort out the ffmpeg deps to reduce conditionals
* Thu Dec  3 2015 dmueller@suse.com
- only depend on luajit on compatible architectures (doesn't
  exist on e.g. aarch64)
* Tue Nov 10 2015 idonmez@suse.com
- Update to v0.13.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.13.0
    for the complete changelog.
* Thu Oct 29 2015 idonmez@suse.com
- Update to v0.12.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.12.0
    for the complete changelog.
* Fri Oct 23 2015 idonmez@suse.com
- Add a 265x256 resolution app icon
* Wed Sep 23 2015 idonmez@suse.com
- Update to v0.11.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.11.0
    for the complete changelog.
* Fri Sep  4 2015 tchvatal@suse.com
- Bump version of WAF to match upstream
* Fri Sep  4 2015 idonmez@suse.com
- Update to v0.10.0
  * Please see https://github.com/mpv-player/mpv/releases/tag/v0.10.0
    for the complete changelog.
* Wed May 27 2015 tchvatal@suse.com
- Try to fix build for both Factory and packman
  * We neeed to sync this up
* Wed May 27 2015 tchvatal@suse.com
- Version bump to 0.9.2:
  * Various opengl fixes
  * Fulscreen behaviour fixes for some WMs
  * Various other small fixes
* Tue May 19 2015 olaf@aepfle.de
- Sync buildrequires with packman spec-file
* Fri May 15 2015 tchvatal@suse.com
- Sync with packman spec-file
* Wed May  6 2015 mpluskal@suse.com
- Update to 0.9.1
  * mpv's IRC channel moved from #mpv-player to #mpv on chat.freenode.net.
  * Documentation updates.
  * The default value for the --ytdl-format option is now best, in order to work around youtube-dl's 2015.04.26 release enabling DASH by default, as FFmpeg / Libav do not yet properly support DASH.
  * When seeking, the current timestamp will show the predicted seek timestamp instead, until the final timestamp is resolved. Improves UI responsiveness on slow streams and/or large seeks.
- Changes for 0.9.0
  * Note: mpv is not compatible with Lua 5.3. Lua 5.1 or 5.2 is required.
  * The minimum required libass version is now 0.12.1 or newer.
  * The minimum required FFmpeg version is now 2.4.0 (equiv. Libav 11) or newer.
  * The internal libmpg123 support was removed. This was already not used by default in the previous release.
  * The LIRC support was removed. Configure LIRC remotes as input devices instead.
  * The Linux Joystick support was removed.
  * vf_screenshot was removed, as they are now handled at a VO level and is compatible with all VOs.
  * --ass-use-margins has been renamed to --sub-use-margins and applies only to plain-text (non-ASS) subtitles (enabled by default). The new --ass-force-margins option applies only to ASS subtitles (disabled by default). To get the old behaviour back, enable both at the same time.
  * The --sub-scale-with-window option now only applies to plain text (non-ASS) subtitles (enabled by default). The new --ass-scale-with-window option does the same but only with ASS subtitles (disabled by default).
  * The range for the param1 for the gaussian vo_opengl scaler has been redefined. Instead of being an arbitrary 1-100 range, have a default value of 1.0, and anything higher is blurrier.
  * The seek, playlist_next, playlist_prev, loadfile and loadlist parameters no longer accept numerical parameters where symbolic parameter names exist.
  * vo_opengl changes:
  * The smoothmotion suboption has been renamed to interpolation. The old name is still supported for now.
  * The bilinear_slow scaler has been renamed to triangle.
  * scale-down has been renamed to dscale and now has its own set of config options (e.g. dscale-radius).
  * Scaler radius no longer defaults to 3 but to a preferred value that may be different for each filter.
  * The scale-radius option may now go down as low as 0.5, which is the value used by the nearest filter.
  * spline36 is the new cscale default for opengl-hq. This might break setups that use fbo-format=rgb8. To work around it, leave fbo-format as its default, or set to something higher than 8, or set cscale=bilinear, the previous default.
  * vf_format no longer converts video to YUYV if there is no parameter. Video is now passed unchanged unless a format is specifically requested.
  * The --colormatrix, --colormatrix-input-range, --colormatrix-output-range and --colormatrix-primaries options have been converted into vf_format suboptions. See commit 27715b7 and the manual for details.
  * vf_mirror's implementation was replaced with calling into libavfilter's vf_hflip filter, thus depending on libavfilter to function.
  * The device subption to ao_wasapi has been deprecated in favor of --audio-device.
  * --video-rotate now allows 360 as an argument instead of stopping at 359.
  * Several improvements to af_scaletempo.
  * Options that have multiple options and also include a "yes" option now default to that if specified with no arguments.
  * The default value of --cache-default is now 150000 (153.6 MB, ~146 MiB).
  * JPEG screenshots now use the same subsampling as the source video. The images are still RGB regardless of source format though.
* Thu Apr 23 2015 mpluskal@suse.com
- Correct category for library
- Add post/postun scriplet to update icons cache
* Wed Apr 22 2015 mpluskal@suse.com
- Update dependencies (explicitly depend on libav for now)
* Sat Mar 21 2015 mpluskal@suse.com
- Use url for source
- Minor spec file cleanups
* Fri Mar 20 2015 mermoldy@gmail.com
- Version bump to 0.8.3:
  Changes
  * Documentation fixes and updates.
  * (Client API) Clarify mpv_opengl_cb_render's viewport parameter behavior.
  Bug fixes
  * (X11) Fix crash on vo_xv:no-colorkey with the Overlay adapter. (bug #1629)
  * Make the video equalizer work correctly on some VAAPI drivers. (bug #1647)
  * Prevent OSD from disappearing when clicking on mozplugger. (bug #1672)
  * The new DVB-S2 support code, using S2API, now builds on FreeBSD.
  * Fix decoding of seekable matroska from unseekable network stream. (bug #1656)
  * (OSX) Fix crashing when closing a VO's window (usually at exit). (bug #1657)
  * (OSX) Unhide the mouse cursor when over the Dock or Launchpad. (bug #513)
  * (OSX) Fix mouse cursor autohiding when the player is fullscreen.
  * vf_vavpp (VAAPI postprocessing) now deinterlaces video correctly.
  * smb:// streams now use the stream cache (used to be inefficient).
  * (Windows) Do not hide the mouse cursor when it is hovering the window menu.
  * Fix 8-channel output on ao_jack. (bug #1688)
  * Fix --mf-fps parameter on JPEG files. (bug #1689)
  * Fix anamorphic scaling being ignored if it was very minor.
* Fri Jan 30 2015 scarabeus@opensuse.org
- Add BSD-3-Clause license as it is what waf is under
* Thu Jan 29 2015 aloisio@gmx.com
- Version bump to 0.7.3:
  Changes
  * Several documentation updates and typo fixes.
  * Don't show "0%%" position when the stream is infinite / has
    unknown length.
  * Fixes the config file loading order so that lower priority
    `mpv.conf` files don't override higher priority `config` files.
  * The subtitle decoder now gets reset when cycling subtitles.
    This makes the currently shown subtitle event disappear even if
    cycling back to the current subtitle track.
  * `--shuffle` and `--merge-files` now affects the contents of
    playlist files, instead of just the list of files given as
    arguments to mpv.
  * (Linux) `ao_alsa` now deals better with audio device
    disconnection.
  Bug fixes
  * Fixes for handling mono audio on various AOs.
  * (Linux) Fixes resuming from suspend on ao_alsa.
  * Fixes for playlist file parsing.
  * Fix rendering resolution of certain DVB subtitles (bug #1425).
  * Fix EDL or --merge-files breaking timestamps with .avi files.
  * Workaround for libavcodec bug with the VP9 codec parser
    (bug #1448), fixes possible crash.
  * Improve robustness of the matroska parser with broken files
    (bugs #1457, #1461).
  * Improve 10bit video compatibility with older GPUs (specially Intel)
    (bug #1383).
  * Fixes flashing the VO window when playing a list of files that
    includes non-media files (bug #1459).
  * Workaround for window embedding in OpenBox (bug #1235)
  * Fixes for several crashes and lockups (bugs #838, #1389, #1408,
    [#1463], #1473, #1474).
  * Fixes for the zsh completion script (bugs #997)
  New features
  * mpv now prints the contents of its config.h when running in
    verbose mode, to aid with debugging.
  * The `include=` option now accepts `~` to refer to the HOME dir
    (bug #1406).
  * `af_volume` now prints ReplayGain values in verbose mode.
  * m3u playlists that don't have the `#EXTM3U` header are now
    accepted if they "look like" ASCII or UTF-8 text and have the
    .m3u extension.
  * Chapter marks in the seek bar now update when switching files.
  * Supports embedded cover art in MKV files (bug #1374).
  * (Linux) vo_wayland now supports key modifiers (Meta, Alt,
    Control, Shift)
* Thu Dec 25 2014 scarabeus@opensuse.org
- Version bump to 0.7.2:
  * update waf to 0.8.5
  * Give precedence to the DVD menu navigation keyboard bindings so that user
    defined LEFT/RIGHT/... bindings don't break DVD menu navigation.
  * Try to fallback to the "default" device if the selected device is busy in
    the alsa AO.
  * Restore ab-loop settings with playback resume.
  * Don't signal an error if --stream-dump is used.
  * Fix removing key bindings from Lua scripts.
  * Reject channel descriptions with too many channels in the coreaudio AO.
  * Don't async redraw when waiting for VO redraw on OS X (this fixes the very
    annoying glitch where the black bars disappear for a single frame when
    going fullscreen).
  * Fix mono playback with the also AO.
  * Don't crash if framebuffers are not available in the opengl VO.
* Sat Dec 20 2014 seife+obs@b1-systems.com
- fix the UNKNOWN replacement :-)
* Tue Dec 16 2014 scarabeus@opensuse.org
- Replace the UNKNOWN in --version with date from changelog
* Sun Dec 14 2014 scarabeus@opensuse.org
- Quvi was dropped so remove it from the deps
* Fri Dec  5 2014 scarabeus@opensuse.org
- Version bump to 0.7.1:
  * Don't show the volume neutral marker on the OSD if softvol is disabled.
  * Don't select a subtitle track when executing the sub_add input command in "auto" mode.
  * Fix busy loop when seeking while paused (this fixes a problem with pulseaudio that caused mpv and the pulseaudio daemon to use 100%% CPU).
  * Fix Lua function utils.subprocess() in Windows versions older than Vista.
  * Avoid creating a window bigger than the screen on Windows.
  * Don't ignore the last line in m3u playlists.
  * Don't crash if a codec could not be opened.
  * Dynamically allocate audio channel map entries (this should fix a crash in the alsa and coreaudio AOs with audio devices that support more than 20 channel maps).
  * Ignore the "srgb" option in the opengl VO if hardware decoding is enabled.
  * Linearize non-RGB sRGB files correctly (eg. JPEG).
  * Fix opening reference URLs (.file/id=) on OS X.
  * Buffer partial log messages in the client API (the client API will now only pass full log messages to clients).
  * Remove ncurses/terminfo/termcap support (it was disabled by default and replaced by new code since v0.6.0).
  * Enable cdda:// support by default again (it was disabled since v0.6.0).
  * Cascade-load input.conf (if there are several input.confs in the set of valid config paths, load them all).
  * Draw the OSD twice in 3D mode (this fixes subtitles display in 3D mode).
  * Make wasapi the default AO on Windows again since many of its problems have been solved.
  * Use "site-functions" subdir to install the zsh completion script instead of the Debian-specific "vendor-completions" (also provide the --zshdir waf configure option for changing this value).
  * Improve synchronization between the Cocoa GUI and the player (this fixes some long standing deadlock issues on Mac OS X).
  * Remove --fs-missioncontrol option (only relevant to Mac OS X).
  * Enable pitch correction by default when playing at higher speeds (this can be controlled with the --audio-pitch-correction option).
  * Open stream and demuxer asynchronously (this should avoid having the player get blocked on network streams).
  * Add cache-buffering-state property for querying the cache fill status until the player unpauses.
  * Add support for listing and selecting the audio device (note that it is not implemented for all AOs, see the --audio-device option for more information).
  * Add support for a JSON-based IPC mechanism (note that this is not currently supported on Windows, see the JSON IPC section in the manpage for more information).
  * Add Lua utility function for starting processes (see utils.subprocess() in the manpage).
  * Add Lua utility function for parsing JSON (see utils.parse_json() in the manpage).
  * Add field-dominance property (see --field-dominance option).
  * Add video-rotate property (see --video-rotate option).
  * Add playback-abort property for querying whether playback is stopped or is to be stopped.
  * Add cursor-autohide property (see --cursor-autohide option).
  * Add vo-configured property for querying whether a window is created.
  * Add support for dxva2 hardware acceleration on Windows.
  * Drop libquvi support (this has been replaced by a built-in Lua script that invokes the youtube-dl tool, which needs to be installed, see the --ytdl option).
  * Add support for loading chapters from an external file (see the --chapters-file option).
  * Add window-minimized property for querying whether the window is minimized (works for X11 only).
  * Make it possible to configure the OSC seekbar style (see the "seekbarstyle" OSC option).
  * Add support for libmpv on Mac OS X (it used to be broken, now it's fully functional and also provides support for embedding the mpv window inside a Cocoa/Qt application).
  * Try to use the audio channel map reported by ALSA in the alsa AO.
  * Add option to disable text OSD rendering completely (useful for working around certain fontconfig issues, see the --use-text-osd option).
* Mon Nov 24 2014 scarabeus@opensuse.org
- Add --enable-libmpv-shared to build shared library.
* Mon Nov 24 2014 scarabeus@opensuse.org
- Revert back to support wayland.
* Fri Nov 21 2014 scarabeus@opensuse.org
- Blacklist the wayland as it for some reason now have trouble properly
  linking resulting in unresolvable package
* Mon Oct 27 2014 scarabeus@opensuse.org
- Version bump to 0.6.2:
  * The --ass-style-override option now requires a newer version of libass.
  * Correctly signal EOF when using --frames.
  * Strictly endorce the limit imposed by --frames (i.e. avoid producing an extra frame at the end).
  * Fix \x-style escaping when parsing commands.
  * Correctly handle ^h key on the terminal (this should fix the when inserted from Backspace key on new versions of xterm).
  * Don't put the player to sleep after audio reinit.
  * Properly exit if both audio and video fail to initialize.
* Thu Oct 16 2014 scarabeus@opensuse.org
- Version bump to 0.6.1:
  * Don't show message on "osd" command by default (this essentially reverts a change introduced in the last release).
  * Add an alternative input configuration that reverts the key binding changes introduced by previous releases (see etc/restore-old-bindings.conf in the sources).
  * Automatically install example input configuration files.
  * Fix stream languages with Bluray
  * Don't try to create surfaces of size 0 in the VDPAU vo.
  * Don't print audio/video init failure message twice.
  * Fix playback on the root window on X11 (i.e. when using --wid=0).
  * Fix the autodetection of the input format in the vf_stereo3d filter when mpv is built against libav (this makes --video-stereo-mode work with libav as well).
  * Fix compilation with PulseAudio 1.0.
  * Fix compilation with clang.
  * Try harder to decode cover art picture only once.
  * Fix cursor autohide (--cursor-autohide) with audio-only files on file change (e.g. when skipping to the next playlist file).
* Wed Oct  1 2014 aloisio@gmx.com
- Version bump to 0.6.0
  * Numerous changes and new features, see official changelog
* Thu Sep 11 2014 scarabeus@opensuse.org
- Version bump to 0.5.3:
  * Do not honor XDG_CONFIG_DIRS to always read global configs
  * Fix speed behaviour changes
  * Seeking fixes
  * Handle EOF better
* Fri Aug 29 2014 scarabeus@opensuse.org
- Version bump to 0.5.1:
  * Various changes with major release
  * Also look in XDG folders for config
  * Default config renamed to mpv.conf
* Mon Aug  4 2014 scarabeus@opensuse.org
- Version bump to 0.4.2:
  * Fix --cache-file operation when file size is unknown (e.g. when playing from a pipe).
  * Don't sleep if playback is stopped when reconnecting for remote stream.
  * Suspend read on vts change even if the requested title is not found when using dvdnav (dvd://) (this fixes a bug where the DVD menu was not shown properly after a DVD track ended).
  * Avoid draining if the audio output is paused (this fixes a bug where mpv would hang when switching tracks when paused).
  * Drop buffered audio when switching tracks or filters (this fixes a possible regression when using gapless audio).
  * Reverse video rotation direction.
  * Fix initialization of the input when playing from a pipe.
  * Fix description of the --mf option in the manpage (the --mf syntax changed a while ago, but was not documented).
  * Actually append entries to the end of the playlist instead of after the current entry with the "loadlist append" command.
* Sun Jul 13 2014 scarabeus@opensuse.org
- Version bump to 0.4.1:
  * Various small bugfixes
* Tue Jul  1 2014 scarabeus@opensuse.org
- Version bump to 0.4.0:
  * Manpages generating now uses only rst2...
  * Enforce enabling cdda
  * Update requirement for new waf tarball
  + Use dvdnav for dvd:// parsing
  + Various cli arguments changed name see --help for changes
  + Removed radio support
  + For more read https://github.com/mpv-player/mpv/releases/tag/v0.4.0
* Mon Jun 23 2014 scarabeus@opensuse.org
- Version bump to 0.3.11:
  * Small fixes
  * Fix to build with latest git ffmpeg
* Mon May 26 2014 scarabeus@opensuse.org
- Version bump to 0.3.10
  * Various small fixes.
* Wed Apr 30 2014 scarabeus@opensuse.org
- Version bump to 0.3.9:
  * Various small fixes.
* Sun Apr 20 2014 scarabeus@opensuse.org
- Version bump to 0.3.8:
  * Bugfixes around vo=vdpau mostly
* Mon Mar 31 2014 scarabeus@opensuse.org
- Version bump to 0.3.7:
  * Small bugfixes especially around old ffmpeg/libav versions.
* Wed Mar 12 2014 scarabeus@opensuse.org
- Version bumjp to 0.3.6:
  * Various minor bug fixes.
* Sun Feb 16 2014 scarabeus@opensuse.org
- Version bump to 0.3.5:
  * use the c99 to avoid few issues
  * fixes in vo_opengl output
* Tue Feb  4 2014 scarabeus@opensuse.org
- Version bump to 0.3.4:
  * bugfixes all around
  * disabled quvi 0.9 subtitles as they were too broken
* Thu Jan 16 2014 scarabeus@opensuse.org
- Version bump to 0.3.3:
  * Fixes matroska containers
  * Wayland fixes
* Wed Jan  8 2014 scarabeus@opensuse.org
- Version bump to 0.3.2:
  * Fix regression with autoenabling subtitles with quvi
  * Various unspecified bugfixes
* Mon Jan  6 2014 scarabeus@opensuse.org
- Version bump to 0.3.1, fixing few issues.
* Thu Jan  2 2014 scarabeus@opensuse.org
- Drop support for < 12.3 as even 12.2 will be out of scope in 13
  days.
* Mon Dec 30 2013 scarabeus@opensuse.org
- Enable libv4l.
* Mon Dec 30 2013 scarabeus@opensuse.org
- Version bump to 0.3.0:
  * Feature update in various areas, notably support for dvdnav
  * Build system was rewritten under waf
  * Multiple subtitles can be now displayed at once
  * vdpau/vaapi acceleration can be used with opengl output
- Run .desktop file updaters
* Sun Dec  8 2013 scarabeus@opensuse.org
- Version bump to 0.2.4:
  * Audio fixes
  * Small bugfixes
* Sat Nov 23 2013 scarabeus@opensuse.org
- Reduce pkgconfig deps where it seems proper.
* Sat Nov 23 2013 scarabeus@opensuse.org
- Fix docu generating and add luajit dependency.
- Try to convert the deps to pkgconfig syntax.
* Sat Nov  9 2013 scarabeus@opensuse.org
- Verison bump to 0.2.3:
  * Handle more signals
  * Fix audio detection with some formats
  * More tiny fixes
* Wed Nov  6 2013 scarabeus@opensuse.org
- Version bump to 0.2.2:
  * Tiny bugfixes
- Depend on rst2tex when available, still broken configure check
  to be fixed next time.
* Mon Oct 21 2013 scarabeus@opensuse.org
- Version bump to 0.2.1:
  * Various small fixes
- Fix build with samba again, fixed in git properly for next
  release.
* Thu Oct 17 2013 scarabeus@opensuse.org
- Fix directory ownership on icondirs.
* Thu Oct 17 2013 scarabeus@opensuse.org
- Version bump to 0.2.0:
  * new icon
  * Add an On Screen Controller (OSC)
  * Subtitles: make automatic charset detection the default
  * More intuitive chapter seeking behavior
  * support for VA-API hardware decoding and display
  * Preliminary Lua scripting support
  * Switch to GPL version 2 or later for mpv as a whole
* Tue Sep 24 2013 scarabeus@opensuse.org
- Install configuration examples for users to inspire themselves.
* Mon Sep 23 2013 scarabeus@opensuse.org
- Version bump to 0.1.7:
  * manpage fixes
  * mkv subtitle fixes
  * various bugfixes
* Mon Sep 16 2013 scarabeus@opensuse.org
- Make mpv build on 12.2 too, what a release.
* Mon Sep 16 2013 scarabeus@opensuse.org
- Disable jack on 11.4 so the package actually builds.
* Mon Sep 16 2013 scarabeus@opensuse.org
- And make 11.4 happy too wrt dep resolution.
* Mon Sep 16 2013 scarabeus@opensuse.org
- Make this work with older releases too (versioned ifs for deps).
* Sun Sep 15 2013 scarabeus@opensuse.org
- Update license and ship readme.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Fix description.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Fix dep on python3-docutils as they are borked now, use py2 for
  time being, told sachpe to figure it out.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Sort out remaining dependencies so we can build.
* Sun Sep 15 2013 scarabeus@opensuse.org
- Initial spec file for mpv media player.
  * Based from mplayer2 spec.
